Documentation
¶
Rendered for windows/amd64
Overview ¶
Package win32 implements a partial shiny screen driver using the Win32 API. It provides window, lifecycle, key, and mouse management, but no drawing. That is left to windriver (using GDI) or gldriver (using DirectX via ANGLE).
Index ¶
- Variables
- func AddScreenMsg(fn func(hwnd syscall.Handle, uMsg uint32, wParam, lParam uintptr)) uint32
- func AddWindowMsg(fn func(hwnd syscall.Handle, uMsg uint32, wParam, lParam uintptr)) uint32
- func GetDC(hwnd syscall.Handle) (dc syscall.Handle, err error)
- func Main(f func()) (retErr error)
- func NewWindow(opts *screen.NewWindowOptions) (syscall.Handle, error)
- func Release(hwnd syscall.Handle)
- func ReleaseDC(hwnd syscall.Handle, dc syscall.Handle) (err error)
- func SendMessage(hwnd syscall.Handle, uMsg uint32, wParam uintptr, lParam uintptr) (lResult uintptr)
- func SendScreenMessage(uMsg uint32, wParam uintptr, lParam uintptr) (lResult uintptr)
- func Show(hwnd syscall.Handle)
Constants ¶
This section is empty.
Variables ¶
Functions ¶
func AddScreenMsg ¶
func AddWindowMsg ¶
func SendMessage ¶
func SendScreenMessage ¶
func Show ¶
Show shows a newly created window. It sends the appropriate lifecycle events, makes the window appear on the screen, and sends an initial size event.
This is a separate step from NewWindow to give the driver a chance to setup its internal state for a window before events start being delivered.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.